@@ -1,4 +1,4 @@
-from .tictoc import Timer,tic,toc
+from .tictoc import Timer,tic,toc,tic2,toc2
 
 def __get_version():
   import json
